@@ -44,7 +44,7 @@ class Provider(BaseProvider):
         response = self._request_aliyun("DescribeDomainInfo")
 
         if "DomainId" not in response:
-            raise ValueError("failed to fetch basic domain info for %s" % (self.domain))
+            raise ValueError(f"failed to fetch basic domain info for {self.domain}")
 
         self.domain_id = response["DomainId"]
 
@@ -114,7 +114,7 @@ class Provider(BaseProvider):
             identifier = record["id"] if record else None
 
         if not identifier:
-            raise ValueError("updating %s identifier not exists" % identifier)
+            raise ValueError(f"updating {identifier} identifier not exists")
 
         if len(resources) > 1:
             LOGGER.warning(
