@@ -87,7 +87,7 @@ class Provider(BaseProvider):
             domain_id = self.rpc_helper.authenticate()
             self.domain_id = domain_id
         else:
-            self._get("/domains/{0}".format(self.domain))
+            self._get(f"/domains/{self.domain}")
             self.domain_id = self.domain.lower()
 
     def _create_record(self, rtype, name, content):
@@ -104,8 +104,8 @@ class Provider(BaseProvider):
         ]
         if current_values != [content]:
             # a change is necessary
-            url = "/domains/{0}/records/{1}/{2}".format(
-                self.domain_id, self._relative_name(name), rtype
+            url = (
+                f"/domains/{self.domain_id}/records/{self._relative_name(name)}/{rtype}"
             )
             if current_values:
                 record = {"rrset_values": current_values + [content]}
@@ -142,19 +142,15 @@ class Provider(BaseProvider):
                 if rtype is not None:
                     query_results = [
                         self._get(
-                            "/domains/{0}/records/{1}/{2}".format(
-                                self.domain_id, self._relative_name(name), rtype
-                            )
+                            f"/domains/{self.domain_id}/records/{self._relative_name(name)}/{rtype}"
                         )
                     ]
                 else:
                     query_results = self._get(
-                        "/domains/{0}/records/{1}".format(
-                            self.domain_id, self._relative_name(name)
-                        )
+                        f"/domains/{self.domain_id}/records/{self._relative_name(name)}"
                     )
             else:
-                query_results = self._get("/domains/{0}/records".format(self.domain_id))
+                query_results = self._get(f"/domains/{self.domain_id}/records")
                 if rtype is not None:
                     query_results = [
                         item for item in query_results if item["rrset_type"] == rtype
@@ -206,15 +202,13 @@ class Provider(BaseProvider):
                 data["rrset_values"] = [content]
         if rtype is not None:
             # replace the records of a specific rtype
-            url = "/domains/{0}/records/{1}/{2}".format(
-                self.domain_id, identifier or self._relative_name(name), rtype
-            )
+            effect_id = identifier or self._relative_name(name)
+            url = f"/domains/{self.domain_id}/records/{effect_id}/{rtype}"
             self._put(url, data)
         else:
             # replace all records with a matching name
-            url = "/domains/{0}/records/{1}".format(
-                self.domain_id, identifier or self._relative_name(name)
-            )
+            effect_id = identifier or self._relative_name(name)
+            url = f"/domains/{self.domain_id}/records/{effect_id}"
             self._put(url, {"items": [data]})
         LOGGER.debug("update_record: %s", True)
         return True
@@ -242,9 +236,7 @@ class Provider(BaseProvider):
                         for record in matching_records
                         if record["content"] != content
                     ]
-                url = "/domains/{0}/records/{1}/{2}".format(
-                    self.domain_id, self._relative_name(name), current_type
-                )
+                url = f"/domains/{self.domain_id}/records/{self._relative_name(name)}/{current_type}"
                 if len(matching_records) == len(remaining_values):
                     # no matching item should be removed for this rtype
                     pass
@@ -260,7 +252,7 @@ class Provider(BaseProvider):
             if remove_count == 0:
                 raise Exception("Record identifier could not be found.")
         else:
-            self._delete("/domains/{0}/records/{1}".format(self.domain_id, identifier))
+            self._delete(f"/domains/{self.domain_id}/records/{identifier}")
 
         # is always True at this point, if a non 200 response is returned an error is raised.
         LOGGER.debug("delete_record: %s", True)
@@ -323,7 +315,7 @@ class GandiRPCSubProvider(object):
             self._zone_id = payload["zone_id"]
             return payload["id"]
         except xmlrpclib.Fault as err:
-            raise Exception("Failed to authenticate: '{0}'".format(err))
+            raise Exception(f"Failed to authenticate: '{err}'")
 
     # Create record. If record already exists with the same content, do nothing.
     def create_record(self, rtype, name, content, ttl):
