@@ -1,12 +1,12 @@
 """Module provider for a localzone"""
 from __future__ import absolute_import, print_function
+
 import logging
 import types
 from time import localtime, strftime, time
 
 from .base import Provider as BaseProvider
 
-
 # localzone is an optional dependency of lexicon; do not throw an ImportError if
 # the dependency is unmet.
 try:
@@ -27,24 +27,26 @@ def _increment_serial(self):
     if next_serial <= self.soa.rdata.serial:
         next_serial = self.soa.rdata.serial + 1
 
-    if hasattr(self.soa.rdata, 'replace'):
-        self.soa._data = self.soa._data._replace(rdata=self.soa.rdata.replace(serial=next_serial))  # pylint: disable=protected-access
+    if hasattr(self.soa.rdata, "replace"):
+        self.soa._data = self.soa._data._replace(
+            rdata=self.soa.rdata.replace(serial=next_serial)
+        )
     else:
         self.soa.rdata.serial = next_serial
 
 
 def _patch_zone(zone):
-    zone._increment_serial = types.MethodType(_increment_serial, zone)  # pylint: disable=protected-access
+    zone._increment_serial = types.MethodType(_increment_serial, zone)
 
 
 def provider_parser(subparser):
     """Configure provider parserfor a localzone"""
-    subparser.add_argument(
-        "--filename", help="specify location of zone master file")
+    subparser.add_argument("--filename", help="specify location of zone master file")
 
 
 class Provider(BaseProvider):
     """Provider class for a localzone"""
+
     def __init__(self, config):
         super(Provider, self).__init__(config)
         self.ttl = self._get_lexicon_option("ttl")
@@ -72,7 +74,7 @@ class Provider(BaseProvider):
         with localzone.manage(self.filename, self.origin, autosave=True) as zone:
             # TODO: Remove this monkeypatch once upstream Class is fixed.
             _patch_zone(zone)
-            if zone.add_record(name, rtype, content, ttl=ttl):  # pylint: disable=no-member
+            if zone.add_record(name, rtype, content, ttl=ttl):
                 result = True
 
         LOGGER.debug("create_record: %s", result)
@@ -94,7 +96,7 @@ class Provider(BaseProvider):
         with localzone.manage(self.filename, self.origin, autosave=True) as zone:
             # TODO: Remove this monkeypatch once upstream Class is fixed.
             _patch_zone(zone)
-            records = zone.find_record(**filter_query)  # pylint: disable=no-member
+            records = zone.find_record(**filter_query)
 
         result = []
         for record in records:
@@ -132,7 +134,7 @@ class Provider(BaseProvider):
             with localzone.manage(self.filename, self.origin, autosave=True) as zone:
                 # TODO: Remove this monkeypatch once upstream Class is fixed.
                 _patch_zone(zone)
-                if zone.update_record(identifier, content):  # pylint: disable=no-member
+                if zone.update_record(identifier, content):
                     result = True
 
         LOGGER.debug("update_record: %s", result)
@@ -158,11 +160,11 @@ class Provider(BaseProvider):
                 # TODO: Remove this monkeypatch once upstream Class is fixed.
                 _patch_zone(zone)
                 for hashid in ids:
-                    zone.remove_record(hashid)  # pylint: disable=no-member
+                    zone.remove_record(hashid)
                     LOGGER.debug("delete_record: %s", hashid)
 
         return True
 
-    def _request(self, action='GET', url='/', data=None, query_params=None):
+    def _request(self, action="GET", url="/", data=None, query_params=None):
         # Not required
         pass
